@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Validators
 ==========
@@ -8,20 +7,17 @@ Validators
 
 """
 
-from __future__ import unicode_literals
-
 from datetime import date
 from decimal import Decimal
 
 from django.core import validators
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
 
 from dateutil.parser import parse
 from dateutil.relativedelta import relativedelta
 
 
-class FormidableValidator(object):
+class FormidableValidator:
 
     def to_formidable(self, field):
         return field.validations.create(**self.get_formidable_kwargs())
@@ -68,7 +64,7 @@ class GTValidator(FormidableValidator, validators.BaseValidator):
 
     type = 'GT'
 
-    message = _("Ensure this field is greater than %(limit_value)s")
+    message = "Ensure this field is greater than %(limit_value)s"
 
     def clean(self, x):
         return x
@@ -80,7 +76,7 @@ class GTValidator(FormidableValidator, validators.BaseValidator):
 class LTValidator(FormidableValidator, validators.BaseValidator):
 
     type = 'LT'
-    message = _("Ensure this field is less than %(limit_value)s")
+    message = "Ensure this field is less than %(limit_value)s"
 
     def clean(self, x):
         return x
@@ -92,7 +88,7 @@ class LTValidator(FormidableValidator, validators.BaseValidator):
 class EQValidator(FormidableValidator, validators.BaseValidator):
 
     type = 'EQ'
-    message = _("Ensure this field is equal to %(limit_value)s")
+    message = "Ensure this field is equal to %(limit_value)s"
 
     def clean(self, x):
         return x
@@ -105,7 +101,7 @@ class EQValidator(FormidableValidator, validators.BaseValidator):
 class NEQValidator(FormidableValidator, validators.BaseValidator):
 
     type = 'NEQ'
-    message = _("Ensure this field is not equal to %(limit_value)s")
+    message = "Ensure this field is not equal to %(limit_value)s"
 
     def clean(self, x):
         return x
@@ -118,7 +114,7 @@ class NEQValidator(FormidableValidator, validators.BaseValidator):
 class DateValidator(FormidableValidator):
 
     def __init__(self, limit_value, message=None):
-        super(DateValidator, self).__init__(
+        super().__init__(
             parse(limit_value).date(), message
         )
 
@@ -193,7 +189,7 @@ class AgeUnderValidator(AgeAboveValidator):
         return value >= age
 
 
-class ValidatorFactory(object):
+class ValidatorFactory:
 
     @cached_property
     def maps(self):
@@ -247,6 +243,9 @@ class ValidatorFactory(object):
         """
         Return the tuple of validation type, validation msg, validation value
         """
+        if isinstance(validation, dict):
+            return (validation['type'],
+                    validation['message'], validation['value'])
         return validation.type, validation.message or None, validation.value
 
 
@@ -259,7 +258,8 @@ class DateValidatorFactory(ValidatorFactory):
             'IS_AGE_ABOVE': self.age_above,
             'IS_AGE_UNDER': self.age_under
         }
-        _maps.update(super(DateValidatorFactory, self).maps)
+        _maps.update(super().maps)
+
         return _maps
 
     def lt(self, value, message):
